@@ -3,6 +3,12 @@ package Promise::XS;
 use strict;
 use warnings;
 
+our $VERSION;
+
+BEGIN {
+    $VERSION = '0.12_01';
+}
+
 =encoding utf-8
 
 =head1 NAME
@@ -46,6 +52,12 @@ e.g., C<use Promise::XS qw(deferred)>.
 
 =head1 DESCRIPTION
 
+=begin html
+
+<a href='https://coveralls.io/github/FGasper/p5-Promise-XS?branch=master'><img src='https://coveralls.io/repos/github/FGasper/p5-Promise-XS/badge.svg?branch=master' alt='Coverage Status' /></a>
+
+=end html
+
 This module exposes a Promise interface with its major parts
 implemented in XS for speed. It is a fork and refactor of
 L<AnyEvent::XSPromises>. That module’s interface, a “bare-bones”
@@ -104,16 +116,17 @@ values.
 
 =head2 Empty or uninitialized rejection values
 
-Promise rejections fulfill the same role in asynchronous code that exceptions
-do in synchronous code. Perl helpfully warns (under the C<warnings> pragma,
-anyhow) when you C<die(undef)> since an uninitialized value isn’t useful as
-an error report and likely indicates a problem.
+Perl helpfully warns (under the C<warnings> pragma, anyhow) when you
+C<die(undef)> since an uninitialized value isn’t useful as an error report
+and likely indicates a problem in the error-handling logic.
 
-Promise::XS mimics this behavior by warning if a rejection value list lacks
-a defined value. This can happen if the value list is either empty or
-contains exclusively uninitialized values.
+Promise rejections fulfill the same role in asynchronous code that
+exceptions do in synchronous code. Thus, Promise::XS mimics Perl’s behavior:
+if a rejection value list lacks a defined value, a warning is thrown. This
+can happen if the value list is either empty or contains exclusively
+uninitialized values.
 
-=head2 C<finally()
+=head2 C<finally()>
 
 This module implements ECMAScript’s C<finally()> interface, which differs
 from that in some other Perl promise implementations.
@@ -129,8 +142,8 @@ Given the following …
 =item * If C<$callback> returns anything but a single, rejected promise,
 C<$new> has the same status as C<$p>.
 
-=item * If C<$callback> throws or returns a single, rejected promise,
-C<$new> is rejected with C<$callback>’s exception.
+=item * If C<$callback> throws, or if it returns a single, rejected promise,
+C<$new> is rejected with the relevant value(s).
 
 =back
 
@@ -184,8 +197,7 @@ mid-flight controls like cancellation.
 
 =over
 
-=item * C<all()> and C<race()> should be implemented in XS,
-as should C<resolved()> and C<rejected()>.
+=item * C<all()> and C<race()> should ideally be implemented in XS.
 
 =back
 
@@ -211,9 +223,6 @@ use Promise::XS::Promise ();
 
 our $DETECT_MEMORY_LEAKS;
 
-# Not meant to be altered publicly.
-our $_IN_REJECTED;
-
 use constant DEFERRAL_CR => {
     AnyEvent => \&Promise::XS::Deferred::set_deferral_AnyEvent,
     'IO::Async' => \&Promise::XS::Deferred::set_deferral_IOAsync,
@@ -234,16 +243,6 @@ sub use_event {
     }
 }
 
-sub resolved {
-    return deferred()->resolve(@_)->promise();
-}
-
-sub rejected {
-    local $_IN_REJECTED = 1;
-
-    return deferred()->reject(@_)->promise();
-}
-
 #----------------------------------------------------------------------
 # Aggregator functions
 sub all {
