@@ -3,7 +3,9 @@ package Promise::XS::Loader;
 use strict;
 use warnings;
 
-our $VERSION = '0.10_04';
+use Promise::XS;
+our $VERSION;
+*VERSION = \$Promise::XS::VERSION;
 
 require XSLoader;
 XSLoader::load('Promise::XS', $VERSION);
